const path = require('path');
const WebpackBeforeBuildPlugin = require('../../index');
const { replace_at_file } = require('./fs');

// did you know that webpack@4 uses terser-webpack-plugin that uses `crypto.createHash('md4')` somewhere in the middle?
// and it was prohibited at node 18+? 
// and that causes `Error: error:0308010C:digital envelope routines::unsupported` compilation error
// while webpack@3 and @2 and @1 is ok
// OMG!! SURPRISE!
// [from https://stackoverflow.com/a/69691525/4486609]
const crypto = require("crypto");
const crypto_orig_createHash = crypto.createHash;
crypto.createHash = algorithm => crypto_orig_createHash(algorithm == "md4" ? "sha256" : algorithm);

module.exports = {
  entry: {
    'bundle.js': [
      path.resolve(__dirname, 'src/file1.js'),
      path.resolve(__dirname, 'src/file2.js')
    ]
  },
  output: {
    filename: '[name]',
    path: path.resolve(__dirname, 'dist'),
  },
  plugins: [
    new WebpackBeforeBuildPlugin(function(stats, callback) {
      console.log('---before---');
      replace_at_file('./src/file1.js', /123/g, 'abc');
      callback();
    }),
    new WebpackBeforeBuildPlugin(function(stats, callback) {
      console.log('---after---');
      replace_at_file('./src/file1.js', /abc/g, 'xyz');
      callback();
    }, 'done')
  ]
};